@@ -57,9 +57,10 @@ class ComponentConfig(object):
         'realm',
         'extra',
         'keyring',
+        'controller'
     )
 
-    def __init__(self, realm=None, extra=None, keyring=None):
+    def __init__(self, realm=None, extra=None, keyring=None, controller=None):
         """
 
         :param realm: The realm the session should join.
@@ -75,7 +76,10 @@ class ComponentConfig(object):
             symmetric message key, which in turn is encrypted using the "to" URI (topic being
             published to or procedure being called) public key and the "from" URI
             private key. In both cases, the key for the longest matching URI is used.
-        :type keyring: obj implementing IKeyRing
+        :type keyring: obj implementing IKeyRing or None
+        :param controller: A WAMP ApplicationSession instance that holds a session to
+            a controlling entity.
+        :type controller: instance of ApplicationSession or None
         """
         assert(realm is None or type(realm) == six.text_type)
         # assert(keyring is None or ...) # FIXME
@@ -83,9 +87,10 @@ class ComponentConfig(object):
         self.realm = realm
         self.extra = extra
         self.keyring = keyring
+        self.controller = controller
 
     def __str__(self):
-        return "ComponentConfig(realm=<{0}>, extra={1}, keyring={2})".format(self.realm, self.extra, self.keyring)
+        return "ComponentConfig(realm=<{0}>, extra={1}, keyring={2}, controller={3})".format(self.realm, self.extra, self.keyring, self.controller)
 
 
 class HelloReturn(object):
@@ -362,7 +367,7 @@ class SubscribeOptions(object):
         """
         options = {}
 
-        if self.match:
+        if self.match is not None:
             options[u'match'] = self.match
 
         return options
@@ -496,28 +501,28 @@ class PublishOptions(object):
         """
         options = {}
 
-        if self.acknowledge:
+        if self.acknowledge is not None:
             options[u'acknowledge'] = self.acknowledge
 
-        if self.exclude_me:
+        if self.exclude_me is not None:
             options[u'exclude_me'] = self.exclude_me
 
-        if self.exclude:
+        if self.exclude is not None:
             options[u'exclude'] = self.exclude if type(self.exclude) == list else [self.exclude]
 
-        if self.exclude_authid:
+        if self.exclude_authid is not None:
             options[u'exclude_authid'] = self.exclude_authid if type(self.exclude_authid) == list else self.exclude_authid
 
-        if self.exclude_authrole:
+        if self.exclude_authrole is not None:
             options[u'exclude_authrole'] = self.exclude_authrole if type(self.exclude_authrole) == list else self.exclude_authrole
 
-        if self.eligible:
+        if self.eligible is not None:
             options[u'eligible'] = self.eligible if type(self.eligible) == list else self.eligible
 
-        if self.eligible_authid:
+        if self.eligible_authid is not None:
             options[u'eligible_authid'] = self.eligible_authid if type(self.eligible_authid) == list else self.eligible_authid
 
-        if self.eligible_authrole:
+        if self.eligible_authrole is not None:
             options[u'eligible_authrole'] = self.eligible_authrole if type(self.eligible_authrole) == list else self.eligible_authrole
 
         return options
@@ -535,10 +540,11 @@ class RegisterOptions(object):
     __slots__ = (
         'match',
         'invoke',
+        'concurrency',
         'details_arg',
     )
 
-    def __init__(self, match=None, invoke=None, details_arg=None):
+    def __init__(self, match=None, invoke=None, concurrency=None, details_arg=None):
         """
 
         :param details_arg: When invoking the endpoint, provide call details
@@ -547,10 +553,12 @@ class RegisterOptions(object):
         """
         assert(match is None or (type(match) == six.text_type and match in [u'exact', u'prefix', u'wildcard']))
         assert(invoke is None or (type(invoke) == six.text_type and invoke in [u'single', u'first', u'last', u'roundrobin', u'random']))
+        assert(concurrency is None or (type(concurrency) in six.integer_types and concurrency > 0))
         assert(details_arg is None or type(details_arg) == str)
 
         self.match = match
         self.invoke = invoke
+        self.concurrency = concurrency
         self.details_arg = details_arg
 
     def message_attr(self):
@@ -559,16 +567,19 @@ class RegisterOptions(object):
         """
         options = {}
 
-        if self.match:
+        if self.match is not None:
             options[u'match'] = self.match
 
-        if self.invoke:
+        if self.invoke is not None:
             options[u'invoke'] = self.invoke
 
+        if self.concurrency is not None:
+            options[u'concurrency'] = self.concurrency
+
         return options
 
     def __str__(self):
-        return "RegisterOptions(match={0}, invoke={1}, details_arg={2})".format(self.match, self.invoke, self.details_arg)
+        return "RegisterOptions(match={0}, invoke={1}, concurrency={2}, details_arg={3})".format(self.match, self.invoke, self.concurrency, self.details_arg)
 
 
 class CallDetails(object):
@@ -657,10 +668,10 @@ class CallOptions(object):
         """
         options = {}
 
-        if self.timeout:
+        if self.timeout is not None:
             options[u'timeout'] = self.timeout
 
-        if self.on_progress:
+        if self.on_progress is not None:
             options[u'receive_progress'] = True
 
         return options
